@@ -14,22 +14,30 @@ from sysconfig import get_paths, get_python_version, get_scheme_names
 import pkg_resources
 
 import pipenv
-from pipenv.patched.notpip._vendor.packaging.utils import canonicalize_name
+from pipenv.patched.pip._internal.commands.install import InstallCommand
+from pipenv.patched.pip._internal.index.package_finder import PackageFinder
+from pipenv.patched.pip._internal.req.req_uninstall import UninstallPathSet
+from pipenv.patched.pip._vendor.packaging.utils import canonicalize_name
 from pipenv.utils.constants import is_type_checking
 from pipenv.utils.indexes import prepare_pip_source_args
 from pipenv.utils.processes import subprocess_run
 from pipenv.utils.shell import make_posix, normalize_path
 from pipenv.vendor import click, vistir
-from pipenv.vendor.cached_property import cached_property
+
+try:
+    # this is only in Python3.8 and later
+    from functools import cached_property
+except ImportError:
+    # eventually distlib will remove cached property when they drop Python3.7
+    from pipenv.patched.pip._vendor.distlib.util import cached_property
+
 
 if is_type_checking():
     from types import ModuleType
     from typing import ContextManager, Dict, Generator, List, Optional, Set, Union
 
-    import pip_shims.shims
     import tomlkit
 
-    from pipenv.patched.notpip._vendor.packaging.version import Version
     from pipenv.project import Project, TPipfile, TSource
 
 BASE_WORKING_SET = pkg_resources.WorkingSet(sys.path)
@@ -342,36 +350,28 @@ class Environment:
         pylib_lines = []
         pyinc_lines = []
         py_command = (
-            "import sysconfig, distutils.sysconfig, io, json, sys; paths = {{"
-            "%s }}; value = u'{{0}}'.format(json.dumps(paths));"
-            "fh = io.open('{0}', 'w'); fh.write(value); fh.close()"
+            "import sysconfig, json; paths = {%s};"
+            "value = u'{0}'.format(json.dumps(paths)); print(value)"
         )
-        distutils_line = "distutils.sysconfig.get_python_{0}(plat_specific={1})"
         sysconfig_line = "sysconfig.get_path('{0}')"
         if python_lib:
-            for key, var, val in (("pure", "lib", "0"), ("plat", "lib", "1")):
-                dist_prefix = f"{key}lib"
-                # XXX: We need to get 'stdlib' or 'platstdlib'
-                sys_prefix = "{}stdlib".format("" if key == "pure" else key)
+            for key in ("purelib", "platlib", "stdlib", "platstdlib"):
                 pylib_lines.append(
-                    f"u'{dist_prefix}': u'{{{{0}}}}'.format({distutils_line.format(var, val)})"
-                )
-                pylib_lines.append(
-                    f"u'{sys_prefix}': u'{{{{0}}}}'.format({sysconfig_line.format(sys_prefix)})"
+                    f"u'{key}': u'{{0}}'.format({sysconfig_line.format(key)})"
                 )
         if python_inc:
-            for key, var, val in (("include", "inc", "0"), ("platinclude", "inc", "1")):
-                pylib_lines.append(
-                    f"u'{key}': u'{{{{0}}}}'.format({distutils_line.format(var, val)})"
+            for key in ("include", "platinclude"):
+                pyinc_lines.append(
+                    f"u'{key}': u'{{0}}'.format({sysconfig_line.format(key)})"
                 )
         lines = pylib_lines + pyinc_lines
         if scripts:
             lines.append(
-                "u'scripts': u'{{0}}'.format(%s)" % sysconfig_line.format("scripts")
+                "u'scripts': u'{0}'.format(%s)" % sysconfig_line.format("scripts")
             )
         if py_version:
             lines.append(
-                "u'py_version_short': u'{{0}}'.format(distutils.sysconfig.get_python_version()),"
+                "u'py_version_short': u'{0}'.format(sysconfig.get_python_version()),"
             )
         lines_as_str = ",".join(lines)
         py_command = py_command % lines_as_str
@@ -384,18 +384,13 @@ class Environment:
         :return: The python paths for the environment
         :rtype: Dict[str, str]
         """
-        tmpfile = vistir.path.create_tracked_tempfile(suffix=".json")
-        tmpfile.close()
-        tmpfile_path = make_posix(tmpfile.name)
         py_command = self.build_command(
             python_lib=True, python_inc=True, scripts=True, py_version=True
         )
-        command = [self.python, "-c", py_command.format(tmpfile_path)]
+        command = [self.python, "-c", py_command]
         c = subprocess_run(command)
         if c.returncode == 0:
-            paths = {}
-            with open(tmpfile_path, "r", encoding="utf-8") as fh:
-                paths = json.load(fh)
+            paths = json.loads(c.stdout)
             if "purelib" in paths:
                 paths["libdir"] = paths["purelib"] = make_posix(paths["purelib"])
             for key in (
@@ -420,17 +415,12 @@ class Environment:
         :return: The python include path for the environment
         :rtype: Dict[str, str]
         """
-        tmpfile = vistir.path.create_tracked_tempfile(suffix=".json")
-        tmpfile.close()
-        tmpfile_path = make_posix(tmpfile.name)
         py_command = self.build_command(python_lib=True)
-        command = [self.python, "-c", py_command.format(tmpfile_path)]
+        command = [self.python, "-c", py_command]
         c = subprocess_run(command)
         paths = None
         if c.returncode == 0:
-            paths = {}
-            with open(tmpfile_path, "r", encoding="utf-8") as fh:
-                paths = json.load(fh)
+            paths = json.loads(c.stdout)
             if "purelib" in paths:
                 paths["libdir"] = paths["purelib"] = make_posix(paths["purelib"])
             for key in ("platlib", "platstdlib", "stdlib"):
@@ -476,22 +466,11 @@ class Environment:
         :return: The python include path for the environment
         :rtype: Dict[str, str]
         """
-        tmpfile = vistir.path.create_tracked_tempfile(suffix=".json")
-        tmpfile.close()
-        tmpfile_path = make_posix(tmpfile.name)
-        py_command = (
-            "import distutils.sysconfig, io, json, sys; paths = {{u'include': "
-            "u'{{0}}'.format(distutils.sysconfig.get_python_inc(plat_specific=0)), "
-            "u'platinclude': u'{{0}}'.format(distutils.sysconfig.get_python_inc("
-            "plat_specific=1)) }}; value = u'{{0}}'.format(json.dumps(paths));"
-            "fh = io.open('{0}', 'w'); fh.write(value); fh.close()"
-        )
-        command = [self.python, "-c", py_command.format(tmpfile_path)]
+        py_command = self.build_command(python_inc=True)
+        command = [self.python, "-c", py_command]
         c = subprocess_run(command)
         if c.returncode == 0:
-            paths = []
-            with open(tmpfile_path, "r", encoding="utf-8") as fh:
-                paths = json.load(fh)
+            paths = json.loads(c.stdout)
             for key in ("include", "platinclude"):
                 if key in paths:
                     paths[key] = make_posix(paths[key])
@@ -539,23 +518,6 @@ class Environment:
             return "purelib", purelib
         return "platlib", self.paths["platlib"]
 
-    @property
-    def pip_version(self) -> Version:
-        """
-        Get the pip version in the environment.  Useful for knowing which args we can use
-        when installing.
-        """
-        from pipenv.patched.notpip._vendor.packaging.version import (
-            parse as parse_version,
-        )
-
-        pip = next(
-            iter(pkg for pkg in self.get_installed_packages() if pkg.key == "pip"), None
-        )
-        if pip is not None:
-            return parse_version(pip.version)
-        return parse_version("20.2")
-
     def expand_egg_links(self) -> None:
         """
         Expand paths specified in egg-link files to prevent pip errors during
@@ -643,41 +605,28 @@ class Environment:
         return packages
 
     @contextlib.contextmanager
-    def get_finder(
-        self, pre: bool = False
-    ) -> ContextManager[pip_shims.shims.PackageFinder]:
-        from .vendor.pip_shims.shims import InstallCommand, get_package_finder
+    def get_finder(self, pre: bool = False) -> ContextManager[PackageFinder]:
+        from .utils.resolver import get_package_finder
 
-        pip_command = InstallCommand()
+        pip_command = InstallCommand(
+            name="InstallCommand", summary="pip Install command."
+        )
         pip_args = prepare_pip_source_args(self.sources)
         pip_options, _ = pip_command.parser.parse_args(pip_args)
         pip_options.cache_dir = self.project.s.PIPENV_CACHE_DIR
         pip_options.pre = self.pipfile.get("pre", pre)
-        with pip_command._build_session(pip_options) as session:
-            finder = get_package_finder(
-                install_cmd=pip_command, options=pip_options, session=session
-            )
-            yield finder
+        session = pip_command._build_session(pip_options)
+        finder = get_package_finder(
+            install_cmd=pip_command, options=pip_options, session=session
+        )
+        yield finder
 
     def get_package_info(
         self, pre: bool = False
     ) -> Generator[pkg_resources.Distribution, None, None]:
-        from .vendor.pip_shims.shims import parse_version, pip_version
-
-        dependency_links = []
         packages = self.get_installed_packages()
-        # This code is borrowed from pip's current implementation
-        if parse_version(pip_version) < parse_version("19.0"):
-            for dist in packages:
-                if dist.has_metadata("dependency_links.txt"):
-                    dependency_links.extend(
-                        dist.get_metadata_lines("dependency_links.txt")
-                    )
 
         with self.get_finder() as finder:
-            if parse_version(pip_version) < parse_version("19.0"):
-                finder.add_dependency_links(dependency_links)
-
             for dist in packages:
                 typ = "unknown"
                 all_candidates = finder.find_all_candidates(dist.key)
@@ -1006,24 +955,6 @@ class Environment:
                 result = str(result.path)
         return result
 
-    def get_install_args(self, editable=False, setup_path=None):
-        install_arg = "install" if not editable else "develop"
-        install_keys = ["headers", "purelib", "platlib", "scripts", "data"]
-        install_args = [
-            self.environment.python,
-            "-u",
-            "-c",
-            SETUPTOOLS_SHIM % setup_path,
-            install_arg,
-            "--single-version-externally-managed",
-            "--no-deps",
-            "--prefix={}".format(self.base_paths["prefix"]),
-            "--no-warn-script-location",
-        ]
-        for key in install_keys:
-            install_args.append(f"--install-{key}={self.base_paths[key]}")
-        return install_args
-
     def install(self, requirements):
         if not isinstance(requirements, (tuple, list)):
             requirements = [requirements]
@@ -1083,36 +1014,19 @@ class Environment:
             )
             if monkey_patch:
                 monkey_patch.activate()
-            pip_shims = self.safe_import("pip_shims")
-            pathset_base = pip_shims.UninstallPathSet
-            pathset_base._permitted = PatchedUninstaller._permitted
             dist = next(
                 iter(d for d in self.get_working_set() if d.project_name == pkgname), None
             )
-            pathset = pathset_base.from_dist(dist)
-            if pathset is not None:
-                pathset.remove(auto_confirm=auto_confirm, verbose=verbose)
+            path_set = UninstallPathSet.from_dist(dist)
+            if path_set is not None:
+                path_set.remove(auto_confirm=auto_confirm, verbose=verbose)
             try:
-                yield pathset
+                yield path_set
             except Exception:
-                if pathset is not None:
-                    pathset.rollback()
+                if path_set is not None:
+                    path_set.rollback()
             else:
-                if pathset is not None:
-                    pathset.commit()
-            if pathset is None:
+                if path_set is not None:
+                    path_set.commit()
+            if path_set is None:
                 return
-
-
-class PatchedUninstaller:
-    def _permitted(self, path):
-        return True
-
-
-SETUPTOOLS_SHIM = (
-    "import setuptools, tokenize;__file__=%r;"
-    "f=getattr(tokenize, 'open', open)(__file__);"
-    "code=f.read().replace('\\r\\n', '\\n');"
-    "f.close();"
-    "exec(compile(code, __file__, 'exec'))"
-)
