@@ -3,9 +3,8 @@ from __future__ import annotations
 import re
 from collections.abc import Mapping
 
-from urllib3.util import parse_url
-
 from pipenv.exceptions import PipenvUsageError
+from pipenv.patched.pip._vendor.urllib3.util import parse_url
 from pipenv.utils.constants import MYPY_RUNNING
 
 from .internet import create_mirror_source, is_pypi_url
@@ -20,7 +19,7 @@ def prepare_pip_source_args(sources, pip_args=None):
     if pip_args is None:
         pip_args = []
     if sources:
-        # Add the source to notpip.
+        # Add the source to pip.
         package_url = sources[0].get("url")
         if not package_url:
             raise PipenvUsageError("[[source]] section does not contain a URL.")
